@@ -27,6 +27,7 @@ if BaseDirectory is not None:
 SEARCHES_FILE = CONFIGDIR / "searches.txt"
 TEMPLATES_FILE = CONFIGDIR / "templates.txt"
 LOGFILE = CACHEDIR / (PROGRAMNAME + ".log")
+DEFAULT_TRASHFILE = CONFIGDIR / "trash.txt"
 
 URL_RE = re.compile(r'([A-Za-z][A-Za-z0-9+\-.]*)://([^ ]+)')
 
@@ -41,6 +42,11 @@ DELEGATE_ACTION_NONE = 'none'
 DELEGATE_ACTION_MAIL = 'mail-to'
 DELEGATE_ACTIONS = (DELEGATE_ACTION_NONE, DELEGATE_ACTION_MAIL)
 
+DELETE_OPTION_DISABLED = 'disabled'
+DELETE_OPTION_TRASH = 'trash'
+DELETE_OPTION_PERMANENT = 'permanent'
+DELETE_OPTIONS = (DELETE_OPTION_DISABLED, DELETE_OPTION_TRASH, DELETE_OPTION_PERMANENT)
+
 DEFAULT_SORT_ORDER = 'completed,due_in,priority,linenr'
 DEFAULT_INFO_TIMEOUT = 5
 
@@ -79,6 +85,8 @@ SETTING_AUTO_ID = 'auto-id'
 SETTING_HIDE_SEQUENTIAL = 'hide-sequential'
 SETTING_CLICKABLE = 'clickable'
 SETTING_DAILY_RELOAD = 'daily-reload'
+SETTING_DELETE_IS = 'delete-is'
+SETTING_TRASHFILE = 'trash-file'
 SETTING_INFO_TIMEOUT = 'info-timeout'
 SETTING_ICON_SELECTION = 'selection'
 SETTING_ICON_NOT_DONE = 'not-done'
@@ -112,6 +120,7 @@ SETTING_GK_NEW_AFTER = 'new-subsequent'
 SETTING_GK_EDIT = 'edit'
 SETTING_GK_OPEN_FILE = 'open-file'
 SETTING_GK_TOGGLE_DONE = 'toggle-done'
+SETTING_GK_DELETE_TASK = 'delete-task'
 SETTING_GK_SEARCH = 'search'
 SETTING_GK_TOGGLE_TRACKING = 'toggle-tracking'
 SETTING_GK_OPEN_MANUAL = 'open-manual'
