@@ -27,6 +27,8 @@ DEFAULT_CONFIG = {
             common.SETTING_HIDE_SEQUENTIAL: 'yes',
             common.SETTING_INFO_TIMEOUT: common.DEFAULT_INFO_TIMEOUT,
             common.SETTING_USE_COMPLETION: 'yes',
+            common.SETTING_DELETE_IS: 'disabled',
+            common.SETTING_TRASHFILE: common.DEFAULT_TRASHFILE,
         },
         common.SETTING_GROUP_SYMBOLS: {
             common.SETTING_ICON_SELECTION: '',
@@ -161,9 +163,18 @@ class Configuration:
 
         return result
 
+    def path(self, group, item, default=None):
+        value = self.get(group, item, None)
+
+        if value is None:
+            return default
+
+        return pathlib.Path(value).expanduser().resolve()
+
 
 def get_config(args):
     conf = configparser.ConfigParser(interpolation=None)
+    conf.optionxform = lambda o: o
     conf.read_dict(DEFAULT_CONFIG)
     conffile = pathlib.Path(args.config).expanduser().resolve()
 
