@@ -12,6 +12,7 @@ import curses
 import curses.panel
 import traceback
 import tempfile
+import time
 import subprocess
 import shlex
 import shutil
@@ -63,6 +64,7 @@ SHORT_NAMES = {'quit': 'Quit',
                'submit-input': 'Apply changes',
                'select-file': 'Select file',
                'delegate': 'Delegate task',
+               'delete': 'Delete task',
                'refresh-screen': 'Refresh screen',
                'reload-tasks': 'Reload todo files',
                'comp-next': 'Next completion option',
@@ -1014,7 +1016,7 @@ class HelpScreen(RemappedScrollPanel):
         nav_fncs = ['next-item', 'prev-item', 'page-up', 'page-down',
                     'first-item', 'last-item', 'jump-to']
         edt_fncs = ['toggle-hidden', 'toggle-done', 'edit-task', 'create-task',
-                    'toggle-tracking', 'delegate', 'save-template', 'load-template']
+                    'toggle-tracking', 'delegate', 'save-template', 'load-template', 'delete-task']
         search_fncs = ['search', 'load-search', 'save-search', 'search-context', 'search-project']
         meta_fncs = ['show-help', 'open-manual', 'quit', 'cancel', 'refresh-screen',
                      'reload-tasks']
@@ -1179,6 +1181,7 @@ class CursesApplication(Application):
         self.delegate_to = self.conf.get(common.SETTING_GROUP_GENERAL,
                                          common.SETTING_DELEG_TO).lower().strip()
         if self.delegation_action not in common.DELEGATE_ACTIONS:
+            logging.error(f"Configuration option 'delegate-option' ('{self.delegation_action}') is invalid.")
             self.delegation_action = common.DELEGATE_ACTION_NONE
 
         # behaviour
@@ -1191,6 +1194,35 @@ class CursesApplication(Application):
                                    common.SETTING_SAFE_SAVE, 'y')
         self.use_completion = conf.bool(common.SETTING_GROUP_GENERAL,
                                         common.SETTING_USE_COMPLETION, 'y')
+        self.trash_file = conf.path(common.SETTING_GROUP_GENERAL,
+                                    common.SETTING_TRASHFILE,
+                                    common.DEFAULT_TRASHFILE);
+        self.delete_is = conf.get(common.SETTING_GROUP_GENERAL,
+                                  common.SETTING_DELETE_IS,
+                                  common.DELETE_OPTION_DISABLED)
+        if self.delete_is not in common.DELETE_OPTIONS:
+            logging.error(f"Configuration option 'delete-is' ('{self.delete_is}') is invalid.")
+            self.delete_is = common.DELETE_OPTION_DISABLED
+        self.last_perm_delete = datetime.datetime.now()
+        self.perm_delete_timeout = datetime.timedelta(milliseconds=500)
+
+        # ensure paths to trash file
+        if self.delete_is == common.DELETE_OPTION_TRASH:
+            try:
+                self.trash_file.parent.mkdir(parents=True, exist_ok=True)
+            except OSError as exc:
+                logging.error(f"Could not create path to trash file '{self.trash_file.parent}': {exc}")
+                self.delete_is = common.DELETE_OPTION_DISABLED
+
+        # ensure the trash file can be written
+        if self.delete_is == common.DELETE_OPTION_TRASH:
+            failed = None
+            try:
+                with open(self.trash_file, 'a'):
+                    logging.debug(f"Using trash file {self.trash_file}")
+            except OSError as exc:
+                logging.error(f"Could not open trash file '{self.trash_file}': {exc}")
+                self.delete_is = common.DELETE_OPTION_DISABLED
 
         # external editor
         self.external_editor = self.conf.get(common.SETTING_GROUP_GENERAL,
@@ -1283,6 +1315,7 @@ class CursesApplication(Application):
             'show-help': self.do_show_help,
             'delegate': self.do_delegate,
             'open-manual': utils.open_manual,
+            'delete-task': self.do_delete,
             }
 
         self.search_bar = None
@@ -1940,6 +1973,43 @@ class CursesApplication(Application):
                                        numbered=True))
             self.paint(True)
 
+    def do_delete(self):
+        taskline = self.tasks.selected_item
+        if taskline is None:
+            return
+
+        def _do_delete(t):
+            t.todotxt.tasks.remove(t)
+
+        can_perm_delete = self.last_perm_delete + self.perm_delete_timeout < datetime.datetime.now()
+
+        if self.delete_is == common.DELETE_OPTION_DISABLED:
+            return
+
+        elif self.delete_is == common.DELETE_OPTION_PERMANENT and can_perm_delete:
+            success, _ = self.modify_task(taskline, _do_delete)
+            if success:
+                self.last_perm_delete = datetime.datetime.now()
+                self.info(tr("Task deleted"))
+                self.tasks.paint(True)
+
+        elif self.delete_is == common.DELETE_OPTION_TRASH:
+            # first save the task in the trash
+            trashfile = TodoTxt(self.trash_file)
+            trashfile.parse()
+            trashfile.tasks.append(taskline.task)
+            trashfile.save()
+
+            # attempt to delete the task
+            success, _ = self.modify_task(taskline, _do_delete)
+            if success:
+                self.info(tr("Task moved to trash"))
+                self.tasks.paint(True)
+            else:
+                # deletion was not okay, remove the task again from the trash
+                trashfile.tasks.pop()
+                trashfile.save()
+
     def add_to_search(self, text):
         if len(self.search.text) > 0:
             text = ' ' + text
