@@ -7,6 +7,7 @@ import getpass
 import sys
 import webbrowser
 import os
+import logging
 
 from pytodotxt import Task, TodoTxt
 
@@ -225,6 +226,9 @@ class DecoratedTask:
             return getattr(self._task, name)
         raise AttributeError(name)
 
+    def remove(self):
+        self._task.todotxt.tasks.remove(self._task)
+
     @property
     def description(self):
         return self._task.description
@@ -382,6 +386,14 @@ class TaskDataModel(QtCore.QAbstractTableModel):
         self.dataChanged.emit(index, index)
         return True
 
+    def removeTask(self, index):
+        start = index.row()
+        self.beginRemoveRows(self.createIndex(start, 0), 0, 0)
+        self._tasks.remove(index.data(TASK_ROLE))
+        del index
+        self.endRemoveRows()
+        self.dataChanged.emit(self.createIndex(start, 0), self.createIndex(start+1, 0))
+
     def add_task(self, task):
         count = len(self._tasks)
         self.beginInsertRows(self.createIndex(count-1, 0), count, count)
@@ -986,6 +998,34 @@ class MainWindow(QMainWindow):
         self.auto_id = self.config.bool(common.SETTING_GROUP_GENERAL,
                                         common.SETTING_AUTO_ID)
 
+        self.trash_file = self.config.path(common.SETTING_GROUP_GENERAL,
+                                           common.SETTING_TRASHFILE,
+                                           common.DEFAULT_TRASHFILE);
+        self.delete_is = self.config.get(common.SETTING_GROUP_GENERAL,
+                                         common.SETTING_DELETE_IS,
+                                         common.DELETE_OPTION_DISABLED)
+        if self.delete_is not in common.DELETE_OPTIONS:
+            logging.error(f"Configuration option 'delete-is' ('{self.delete_is}') is invalid.")
+            self.delete_is = common.DELETE_OPTION_DISABLED
+
+        # ensure paths to trash file
+        if self.delete_is == common.DELETE_OPTION_TRASH:
+            try:
+                self.trash_file.parent.mkdir(parents=True, exist_ok=True)
+            except OSError as exc:
+                logging.error(f"Could not create path to trash file '{self.trash_file.parent}': {exc}")
+                self.delete_is = common.DELETE_OPTION_DISABLED
+
+        # ensure the trash file can be written
+        if self.delete_is == common.DELETE_OPTION_TRASH:
+            failed = None
+            try:
+                with open(self.trash_file, 'a'):
+                    logging.debug(f"Using trash file {self.trash_file}")
+            except OSError as exc:
+                logging.error(f"Could not open trash file '{self.trash_file}': {exc}")
+                self.delete_is = common.DELETE_OPTION_DISABLED
+
         self.actionOpen = QtWidgets.QAction(tr("&Open…"), self)
         self.actionQuit = QtWidgets.QAction(tr("&Quit"), self)
         self.openSourcesSeparator = None
@@ -1002,6 +1042,7 @@ class MainWindow(QMainWindow):
         self.actionNewRefTask = QtWidgets.QAction(tr("New &related task"), self)
         self.actionNewAfterTask = QtWidgets.QAction(tr("New &subsequent task"), self)
         self.actionToggleDarkStyle = None
+        self.actionDeleteTask = None
 
         if qdarkstyle is not None:
             self.actionToggleDarkStyle = QtWidgets.QAction(tr("Toggle &dark mode"))
@@ -1009,6 +1050,9 @@ class MainWindow(QMainWindow):
             if self.settings.bool(SETTING_GROUP_MAINWINDOW, SETTING_DARK_MODE, "no"):
                 QtWidgets.QApplication.instance().setStyleSheet(qdarkstyle.load_stylesheet(qt_api='pyqt5'))
 
+        if self.delete_is != common.DELETE_OPTION_DISABLED:
+            self.actionDeleteTask = QtWidgets.QAction(tr("Delete task"), self)
+
         self.actionOpenManual = QtWidgets.QAction(tr("Open &manual"), self)
         self.actionShowAbout = QtWidgets.QAction(tr("&About"), self)
         self.actionShowAboutQt = QtWidgets.QAction(tr("About &Qt"), self)
@@ -1070,6 +1114,9 @@ class MainWindow(QMainWindow):
         self.editMenu.addAction(self.actionNewRefTask)
         self.editMenu.addAction(self.actionNewAfterTask)
         self.editMenu.addAction(self.actionEdit)
+        if self.actionDeleteTask is not None:
+            self.editMenu.addSeparator()
+            self.editMenu.addAction(self.actionDeleteTask)
         self.editMenu.addSeparator()
         self.editMenu.addAction(self.actionDelegate)
         self.editMenu.addSeparator()
@@ -1105,6 +1152,9 @@ class MainWindow(QMainWindow):
                 (common.SETTING_GK_DELEGATE, self.actionDelegate, Qt.WindowShortcut),
                 (common.SETTING_GK_TOGGLE_DARK, self.actionToggleDarkStyle, Qt.ApplicationShortcut),
                 ]
+        if self.actionDeleteTask is not None:
+            keymapping.append((common.SETTING_GK_DELETE_TASK, self.actionDeleteTask, Qt.WindowShortcut))
+
         for name, target, context in keymapping:
             keys = self.config.get(common.SETTING_GROUP_GUIKEYS, name)
             if len(keys) > 0 and target is not None:
@@ -1395,6 +1445,9 @@ class Program:
         self.window.actionDelegate.triggered.connect(self.do_delegate)
         self.window.taskList.activated.connect(self.do_edit)
 
+        if self.window.actionDeleteTask is not None:
+            self.window.actionDeleteTask.triggered.connect(self.do_delete_task)
+
         if len(self.icon.availableSizes()) > 0:
             self.window.setWindowIcon(self.icon)
 
@@ -1498,6 +1551,41 @@ class Program:
             task.todotxt.save(safe=self.safe_save)
             self.window.taskModel.setData(taskindex, task)
 
+    def do_delete_task(self):
+        taskindex = self.window.taskList.get_selected_index()
+        if taskindex is None:
+            return
+
+        if self.window.delete_is == common.DELETE_OPTION_DISABLED:
+            return
+
+        elif self.window.delete_is == common.DELETE_OPTION_PERMANENT:
+            taskindex = self.window.taskModel.ensure_up_to_date(taskindex)
+            if taskindex is not None:
+                task = taskindex.data(TASK_ROLE)
+                task.remove()
+                task.todotxt.save(safe=self.safe_save)
+                self.window.taskModel.removeTask(taskindex)
+
+        elif self.window.delete_is == common.DELETE_OPTION_TRASH:
+            # first save the task in the trash
+            trashfile = TodoTxt(self.window.trash_file)
+            trashfile.parse()
+            trashfile.tasks.append(taskindex.data(TASK_ROLE)._task)
+            trashfile.save()
+
+            # attempt to delete the task
+            taskindex = self.window.taskModel.ensure_up_to_date(taskindex)
+            if taskindex is not None:
+                task = taskindex.data(TASK_ROLE)
+                task.remove()
+                task.todotxt.save(safe=self.safe_save)
+                self.window.taskModel.removeTask(taskindex)
+            else:
+                # deletion was not okay, remove the task again from the trash
+                trashfile.tasks.pop()
+                trashfile.save()
+
     def do_open_source(self):
         filename, ok = QtWidgets.QFileDialog.getOpenFileName(self.window,
                                                              tr("Open Todo.txt File"),
@@ -1633,6 +1721,9 @@ def run_qtui(args):
         return
     fullpath.write_text("-")
 
+    logging.basicConfig(format="[%(levelname)s] %(message)s", filename=args.log_file)
+    logging.getLogger().setLevel(args.log_level.upper())
+
     app = QApplication([])
     app.setApplicationName(common.QTPROGRAMNAME)
     app.setApplicationVersion(version.__version__)
